@@ -207,14 +207,14 @@ def pytest_generate_tests(metafunc):
     if scenarios:
         ids = list()
         for index, item in enumerate(scenarios):
-            if item.get("scenario").get("ignore"):
-                continue
-            if func_name in item.get("scenario").get("exclude", list()):
-                continue
             scenario = item.get("scenario")
             level = scenario.get("level", settings.DEFAULT_CASE_LEVEL).lower()
-
             case_data["level"] = level
+            if scenario.get("ignore"):
+                continue
+            if func_name in scenario.get("exclude", list()):
+                continue
+
             new_marks = marks.copy()
             new_marks.append(level)
             # mark标记
@@ -247,11 +247,10 @@ def pytest_generate_tests(metafunc):
                 logger.error(f"scenario参数化格式不正确:{e}")
                 traceback.print_exc()
                 pytest.exit(ExitCode.SCENARIO_FORMAT_ERROR)
+        if case_data_list:
+            metafunc.parametrize("data", case_data_list, ids=ids, scope="function")
 
-        metafunc.parametrize("data", case_data_list, ids=ids, scope="function")
     else:
-        if case_common.get("ignore"):
-            return
         case_data["_scenario"] = {"data": {}}
         case_data["_ignore_failed"] = case_common.get("ignore_failed", settings.GLOBAL_IGNORE_FAILED)
         level = case_data.get("level", settings.DEFAULT_CASE_LEVEL)
@@ -524,13 +523,18 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     terminalreporter.write(f"跳过用例数: {skipped}\n", yellow=True, bold=True)
     terminalreporter.write(f"用例通过率: {pass_rate}%\n", green=True, bold=True)
     terminalreporter.write("====================================\n", blue=True, bold=True)
-    if "linux" in platform.platform().lower():
-        LarkUtil(settings.LARK_WEBHOOK).send_test_report(
+    if settings.ONLY_LINUX_NOTIFICATION:
+        if "linux" not in platform.platform().lower():
+            return
+    for webhook in settings.LARK_WEBHOOKS:
+        LarkUtil(webhook).send_test_report(
             total=total,
             passed=passed,
             failed=failed,
             skipped=skipped,
-            report_url=os.environ.get("ALLURE_REPORT_URL")
+            report_url=os.environ.get("ALLURE_REPORT_URL"),
+            job_name=os.environ.get("JOB_NAME"),
+            env=CONTEXT.get("env")
         )
 
 
@@ -811,28 +815,30 @@ def sort(case_items):
 
         # 根据组数 创建各组的数组 并插入第一个case
         case_dict = dict()
-        try:
-            for i in range(case_suite_num):
+
+        for i in range(case_suite_num):
+            try:
                 item = ori_name_list[i][1]
                 id = item.callspec.id
 
                 first_part = id.split('#', 1)[-1]
                 index = first_part.split(']')[0]
                 case_dict[index] = [item]
-        except:
-            pass
+            except Exception as e:
+                continue
 
         new_start_index = case_suite_num
         # 以new_start_index为起点 重新遍历items
-        try:
-            for i in range(new_start_index, len(non_custom_scope_items)):
+
+        for i in range(new_start_index, len(non_custom_scope_items)):
+            try:
                 item = non_custom_scope_items[i]
                 id = item.callspec.id
                 first_part = id.split('#', 1)[-1]
                 index = first_part.split(']')[0]
                 case_dict.get(index).append(item)
-        except:
-            pass
+            except Exception as e:
+                continue
 
         index = 0
         for id in case_dict:
