@@ -226,33 +226,34 @@ def get_apps():
             os.path.isdir(os.path.join(CONFIG_DIR, name)) and not name.startswith(("__", "."))]
 
 
-# 匹配合法数字字符串（可含千分位）
-decimal_pattern = re.compile(r'^\d{1,3}(,\d{3})*(\.\d+)?$|^\d+(\.\d+)?$')
+# 匹配整数/小数，允许千分符
+decimal_pattern = re.compile(r"^-?\d{1,3}(?:,\d{3})*(?:\.\d+)?$|^-?\d+(?:\.\d+)?$")
 
 
 def convert_numbers_to_decimal(obj: Any) -> Any:
     if isinstance(obj, str):
-        if decimal_pattern.match(obj):
-            int_part = obj.split('.')[0]
-            if len(int_part) > 10 and "," not in int_part:
-                return obj  # 整数部分超过10位，不转换
+        # 必须包含千分符才尝试转换
+        if "," in obj and decimal_pattern.match(obj):
             try:
                 stripped = obj.replace(",", "")
                 return Decimal(stripped)
             except Exception:
                 return obj
-        else:
-            return obj
+        return obj
+
     elif isinstance(obj, dict):
         return {k: convert_numbers_to_decimal(v) for k, v in obj.items()}
+
     elif isinstance(obj, list):
         return [convert_numbers_to_decimal(item) for item in obj]
+
     elif isinstance(obj, (int, float)) and not isinstance(obj, bool):
-        # 处理原生数值类型
+        # 处理原生数值类型（不涉及千分符）
         int_part = str(obj).split('.')[0]
         if len(int_part) > 10:
             return obj  # 整数部分超过10位，不转换
         return Decimal(str(obj))
+
     else:
         return obj
 
